.. Copyright 2022 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.paypalsupport
--------------------------

.. sidebar:: Behind the scenes

   This module uses `paypal-checkout-serversdk <https://pypi.org/project/paypal-checkout-serversdk/>`_ to
   invoke PayPal's online API and JavaScript SDK.

.. automodule:: reahl.paypalsupport.paypalsupport


.. sidebar:: Examples in this section

   - howtos.paymentpaypal

   Get a copy of an example by running:

   .. code-block:: bash

      reahl example <examplename>


PayPalButtonsPanel
""""""""""""""""""

.. autoclass:: PayPalButtonsPanel
   :members:


PayPalOrder
"""""""""""

.. autoclass:: PayPalOrder
   :members:


PayPalClientCredentials
"""""""""""""""""""""""

.. autoclass:: PayPalClientCredentials
   :members:




